@@ -1,12 +1,13 @@
 package Hailo::Role::Arguments;
 our $AUTHORITY = 'cpan:AVAR';
-$Hailo::Role::Arguments::VERSION = '0.73';
+$Hailo::Role::Arguments::VERSION = '0.74';
 use v5.28.0;
 use Moose::Role;
+use MooseX::Types::Moose ':all';
 use namespace::clean -except => 'meta';
 
 has arguments => (
-    isa           => 'HashRef[Str]',
+    isa           => HashRef[Str],
     is            => 'ro',
     documentation => "Arguments passed from Hailo",
     auto_deref    => 1,
