@@ -1,8 +1,9 @@
 package Hailo::Role::Engine;
 our $AUTHORITY = 'cpan:AVAR';
-$Hailo::Role::Engine::VERSION = '0.73';
+$Hailo::Role::Engine::VERSION = '0.74';
 use v5.28.0;
 use Moose::Role;
+use MooseX::Types::Moose ':all';
 use namespace::clean -except => 'meta';
 
 has storage => (
@@ -13,7 +14,7 @@ has storage => (
 
 has order => (
     required      => 1,
-    isa           => 'Int',
+    isa           => Int,
     is            => 'rw',
     documentation => "Our copy of the current markov order",
 );
