@@ -1,12 +1,13 @@
 package Hailo::Role::Tokenizer;
 our $AUTHORITY = 'cpan:AVAR';
-$Hailo::Role::Tokenizer::VERSION = '0.73';
+$Hailo::Role::Tokenizer::VERSION = '0.74';
 use v5.28.0;
 use Moose::Role;
+use MooseX::Types::Moose ':all';
 use namespace::clean -except => 'meta';
 
 has spacing => (
-    isa     => 'HashRef[Int]',
+    isa     => HashRef[Int],
     is      => 'rw',
     default => sub { {
         normal  => 0,
