@@ -1,21 +1,22 @@
 package Hailo::Storage;
 our $AUTHORITY = 'cpan:AVAR';
-$Hailo::Storage::VERSION = '0.73';
+$Hailo::Storage::VERSION = '0.74';
 use v5.28.0;
 use Moose;
 use MooseX::StrictConstructor;
+use MooseX::Types::Moose ':all';
 use DBI;
 use Hailo::Storage::Schema;
 
 has dbd => (
-    isa           => 'Str',
+    isa           => Str,
     is            => 'ro',
     lazy_build    => 1,
     documentation => "The DBD::* driver we're using",
 );
 
 has dbd_options => (
-    isa           => 'HashRef',
+    isa           => HashRef,
     is            => 'ro',
     lazy_build    => 1,
     documentation => 'Options passed as the last argument to DBI->connect()',
@@ -43,7 +44,7 @@ sub _build_dbh {
 };
 
 has dbi_options => (
-    isa           => 'ArrayRef',
+    isa           => ArrayRef,
     is            => 'ro',
     auto_deref    => 1,
     lazy_build    => 1,
@@ -67,14 +68,14 @@ sub _build_dbi_options {
 }
 
 has _engaged => (
-    isa           => 'Bool',
+    isa           => Bool,
     is            => 'rw',
     default       => 0,
     documentation => 'Have we done setup work to get this database going?',
 );
 
 has sth => (
-    isa        => 'HashRef',
+    isa        => HashRef,
     is         => 'ro',
     lazy_build => 1,
     documentation => 'A HashRef of prepared DBI statement handles',
@@ -86,7 +87,7 @@ sub _build_sth {
 }
 
 has _boundary_token_id => (
-    isa => 'Int',
+    isa => Int,
     is  => 'rw',
 );
 
