@@ -2,6 +2,7 @@ package Hailo::Test;
 use v5.28.0;
 use autodie;
 use Moose;
+use MooseX::Types::Moose ':all';
 use Class::Load qw(try_load_class);
 use Hailo;
 use Test::More;
@@ -31,26 +32,26 @@ sub exhaustive_tests {
 }
 
 has brief => (
-    is => 'ro',
-    isa => 'Bool',
+    is      => 'ro',
+    isa     => Bool,
     default => 0,
 );
 
 has in_memory => (
-    is => 'ro',
-    isa => 'Bool',
+    is      => 'ro',
+    isa     => Bool,
     default => 1,
 );
 
 has exhaustive => (
-    is => 'ro',
-    isa => 'Bool',
+    is      => 'ro',
+    isa     => Bool,
     default => 0,
 );
 
 has tmpdir => (
-    is => 'ro',
-    isa => 'Str',
+    is         => 'ro',
+    isa        => Str,
     lazy_build => 1,
 );
 
@@ -67,12 +68,12 @@ sub _build_tmpdir {
 }
 
 has brain => (
-    is => 'ro',
-    isa => 'Str',
+    is  => 'ro',
+    isa => Str,
 );
 
 has tmpfile => (
-    is => 'ro',
+    is         => 'ro',
     lazy_build => 1,
 );
 
@@ -89,8 +90,8 @@ sub _build_tmpfile {
 }
 
 has hailo => (
-    is => 'ro',
-    isa => "Hailo",
+    is         => 'ro',
+    isa        => 'Hailo',
     lazy_build => 1,
 );
 
@@ -221,7 +222,7 @@ sub _connect_opts {
 
 has storage => (
     is => 'ro',
-    isa => 'Str',
+    isa => Str,
 );
 
 sub train_file {
